Core Schema - NinjaStack Docs
Description: Schema-first agentic backend framework documentation

Skip to content

# Core Schema

## `` entity

Entity and field schema definitions for the Agentic Schema Definition.

### `` StorageEngine

Bases: `str`, `Enum`

Database engine that owns an entity.

### `` FieldType

Bases: `str`, `Enum`

Supported field types across all storage engines.

### `` EmbeddingConfig

Bases: `BaseModel`

Configuration for vectorizing a field.

### `` FieldConstraint

Bases: `BaseModel`

Validation constraints for a field.

### `` FieldSchema

Bases: `BaseModel`

Schema definition for a single field within an entity.

### `` EntitySchema

Bases: `BaseModel`

Schema definition for an entity (table, collection, node, or vector store).